@@ -38,56 +38,63 @@ class ResourcesReview extends JTable
 {
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $resource_id = NULL;
 
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $user_id     = NULL;
 
 	/**
 	 * decimal(2,1)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $rating      = NULL;
 
 	/**
 	 * text
-	 * 
+	 *
 	 * @var string
 	 */
 	var $comment     = NULL;
 
 	/**
 	 * datetime(0000-00-00 00:00:00)
-	 * 
+	 *
 	 * @var string
 	 */
 	var $created     = NULL;
 
 	/**
 	 * int(3)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $anonymous   = NULL;
 
 	/**
 	 * int(11) primary key
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $id          = NULL;
 
+	/**
+	 * tinyint(2)
+	 *
+	 * @var integer
+	 */
+	var $state       = NULL;
+
 	/**
 	 * Constructor
-	 * 
+	 *
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -98,12 +105,12 @@ class ResourcesReview extends JTable
 
 	/**
 	 * Validate data
-	 * 
+	 *
 	 * @return     boolean True if valid, false if not
 	 */
 	public function check()
 	{
-		if (trim($this->rating) == '') 
+		if (trim($this->rating) == '')
 		{
 			$this->setError(JText::_('Your review must have a rating.'));
 			return false;
@@ -113,7 +120,7 @@ class ResourcesReview extends JTable
 
 	/**
 	 * Load a review for a specific user/resource combination
-	 * 
+	 *
 	 * @param      integer $resourceid Resource ID
 	 * @param      integer $userid     User ID
 	 * @return     boolean True on success, False on error
@@ -122,11 +129,11 @@ class ResourcesReview extends JTable
 	{
 		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE resource_id=" . $this->_db->Quote($resourceid) . " AND user_id=" . $this->_db->Quote($userid) . " LIMIT 1");
 
-		if ($result = $this->_db->loadAssoc()) 
+		if ($result = $this->_db->loadAssoc())
 		{
 			return $this->bind($result);
-		} 
-		else 
+		}
+		else
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -135,7 +142,7 @@ class ResourcesReview extends JTable
 
 	/**
 	 * Load a rating for a specific user/resource combination
-	 * 
+	 *
 	 * @param      integer $resourceid Resource ID
 	 * @param      integer $userid     User ID
 	 * @return     integer
@@ -148,7 +155,7 @@ class ResourcesReview extends JTable
 
 	/**
 	 * Get all ratings for a specific resource
-	 * 
+	 *
 	 * @param      integer $resource_id Resource ID
 	 * @return     array
 	 */
@@ -156,7 +163,7 @@ class ResourcesReview extends JTable
 	{
 		$juser = JFactory::getUser();
 
-		if (!$resource_id) 
+		if (!$resource_id)
 		{
 			$resource_id = $this->resource_id;
 		}
@@ -170,26 +177,26 @@ class ResourcesReview extends JTable
 			."\n (SELECT COUNT(*) FROM #__vote_log AS v WHERE v.helpful='no' AND v.category='review' AND v.referenceid=rr.id) AS nothelpful "
 			."\n FROM $this->_tbl AS rr "
 			."\n LEFT JOIN #__vote_log AS v ON v.referenceid=rr.id AND v.category='review' AND v.voter=" . $this->_db->Quote($juser->get('id')) . " "
-			."\n WHERE rr.resource_id=" . $this->_db->Quote($resource_id) . "  ORDER BY rr.created DESC");
+			."\n WHERE rr.resource_id=" . $this->_db->Quote($resource_id) . " AND rr.state IN (1, 3) ORDER BY rr.created DESC");
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Load rating for a specific resource
-	 * 
+	 *
 	 * @param      integer $id     Resource ID
 	 * @param      integer $userid User ID
 	 * @return     array
 	 */
 	public function getRating($id=NULL, $userid)
 	{
-		if (!$userid) 
+		if (!$userid)
 		{
 			$juser = JFactory::getUser();
 			$userid = $juser->get('id');
 		}
 
-		if (!$id) 
+		if (!$id)
 		{
 			$id = $this->resource_id;
 		}
@@ -203,13 +210,13 @@ class ResourcesReview extends JTable
 			."\n (SELECT COUNT(*) FROM #__vote_log AS v WHERE v.helpful='no' AND v.category='review' AND v.referenceid=rr.id) AS nothelpful "
 			."\n FROM $this->_tbl AS rr "
 			."\n LEFT JOIN #__vote_log AS v ON v.referenceid=rr.id AND v.category='review' AND v.voter=" . $this->_db->Quote($userid) . " "
-			."\n WHERE rr.id=" . $this->_db->Quote($id) . " ");
+			."\n WHERE rr.state IN (1, 3) AND rr.id=" . $this->_db->Quote($id) . " ");
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Get the vote for a specific item and user
-	 * 
+	 *
 	 * @param      integer $id       Resource ID
 	 * @param      string  $category Category
 	 * @param      integer $uid      User ID
@@ -217,12 +224,12 @@ class ResourcesReview extends JTable
 	 */
 	public function getVote($id, $category = 'review', $uid)
 	{
-		if (!$id) 
+		if (!$id)
 		{
 			$id = $this->id;
 		}
 
-		if ($id === NULL or $uid === NULL) 
+		if ($id === NULL or $uid === NULL)
 		{
 			return false;
 		}
