@@ -3,7 +3,7 @@
  * @package     Joomla.Platform
  * @subpackage  Database
  *
- * @copyright   Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
+ * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
  * @license     GNU General Public License version 2 or later; see LICENSE
  */
 
@@ -81,12 +81,12 @@ abstract class JTable extends JObject
 	 *
 	 * @since   11.1
 	 */
-	public function __construct($table, $key, &$db)
+	public function __construct($table, $key, $db)
 	{
 		// Set internal variables.
 		$this->_tbl = $table;
 		$this->_tbl_key = $key;
-		$this->_db = &$db;
+		$this->_db = $db;
 
 		// Initialise the table properties.
 		if ($fields = $this->getFields())
@@ -592,6 +592,8 @@ abstract class JTable extends JObject
 	 */
 	public function store($updateNulls = false)
 	{
+		$currentAssetId = null;
+
 		// Initialise variables.
 		$k = $this->_tbl_key;
 		if (!empty($this->asset_id))
