@@ -1,23 +1,25 @@
 <?php
 
+use Hubzero\Content\Migration\Base;
+
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
 /**
  * Migration script for converting joomla upload max units
  **/
-class Migration20131021211223Core extends Hubzero_Migration
+class Migration20131021211223Core extends Base
 {
 	/**
 	 * Up
 	 **/
-	protected static function up($db)
+	public function up()
 	{
-		if ($db->tableExists('#__extensions'))
+		if ($this->db->tableExists('#__extensions'))
 		{
 			$query = "SELECT `extension_id`, `params` FROM `#__extensions` WHERE `element` = 'com_media'";
-			$db->setQuery($query);
-			$result = $db->loadObject();
+			$this->db->setQuery($query);
+			$result = $this->db->loadObject();
 
 			if ($result)
 			{
@@ -27,9 +29,9 @@ class Migration20131021211223Core extends Hubzero_Migration
 				{
 					$params->upload_maxsize = $params->upload_maxsize / 1000000;
 
-					$query = "UPDATE `#__extensions` SET `params` = " . $db->quote(json_encode($params)) . " WHERE `extension_id` = " . $db->quote($result->extension_id);
-					$db->setQuery($query);
-					$db->query();
+					$query = "UPDATE `#__extensions` SET `params` = " . $this->db->quote(json_encode($params)) . " WHERE `extension_id` = " . $this->db->quote($result->extension_id);
+					$this->db->setQuery($query);
+					$this->db->query();
 				}
 			}
 		}
