@@ -15,17 +15,10 @@ class Migration20140421112851ComTools extends Base
 	 **/
 	public function up()
 	{
-		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'mw.utils.php');
-
-		$mwdb = MwUtils::getMWDBO();
-
-		if (!$mwdb->connected())
+		if (!$mwdb = $this->getMWDBO())
 		{
-			$return = new \stdClass();
-			$return->error = new \stdClass();
-			$return->error->type = 'warning';
-			$return->error->message = 'Failed to connect to the middleware database';
-			return $return;
+			$this->setError('Failed to connect to the middleware database', 'warning');
+			return false;
 		}
 
 		/* We can just drop the old tables because they were never used on a live hub */
